<?php
/**
 * Compras\Logic\SolicitacaoCompras\Exception
 *
 * @category Php
 * @package  Compras\Logic\SolicitacaoCompras\Exception
 * @author   setforms <setforms@setforms.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Compras\Logic\SolicitacaoCompras\Exception;

/**
 * Class CamposNaoPreenchidos
 *
 * @category Php
 * @package  Compras\Logic\SolicitacaoCompras\Exception
 * @author   setforms <setforms@setforms.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class CamposNaoPreenchidos extends \Compras\Logic\Exception
{

    private $messageName;

    /**
     * Construtor.
     *
     * Recebe o nome da mensagem cadastrada no setforms.
     *
     * @param string     $messageName MessageName
     * @param string     $message     Message
     * @param int        $code        Code
     * @param \Exception $previous    Previous
     */
    public function __construct($messageName, $message = "", $code = 0, \Exception $previous = null)
    {
        parent::__construct($message, $code, $previous);
        $this->messageName = $messageName;
    }

    /**
     * Retorna o nome da mensagem cadastrada no Setforms para esta excecao.
     *
     * @return string
     */
    public function getMessageName()
    {
        return $this->messageName;
    }

    /**
     * Exececao solicitacao nao salva
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function solicitacaoNaoSalva()
    {
        throw new self(
            "solicitacao_nao_salva",
            "Não existe registros associados aos itens que você está tentando inserir. Salve primeiro a solicitação."
        );
    }

    /**
     * Excecao lancada para o caso de uma lista de produtos a ser importada nao possuir os dados de Produtos inicial e
     * final e data de entrega.
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function gravacaoListaProdutos()
    {
        throw new self(
            "campos_obrigatorios_gravacao_lista_produtos",
            "Os campos de Produto Inicial, Produto Final e Data Entrega devem ser informados."
        );
    }

    /**
     * Excecao lancada para o caso de importacao de solicitacao, quando a Filial solicitante, o numero da solicitacao
     * ou a data de entrega nao forem informados.
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function importacaoSolicitacao()
    {
        throw new self(
            "campos_obrigatorios_importacao_solicitacao",
            "Os campos de Filial Solicitante, Nº da Solicitação e Data de Entrega devem ser informados"
        );
    }

    /**
     * Mensagem padrao para casos onde ha campos nao preenchidos.
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function mensagemPadrao()
    {
        throw new self(
            "msg_preencher_campos",
            "Favor preencher todos os campos."
        );
    }
    
    /**
     * Excecao lancada para o caso de Produtos inicial n�o ser preeenchido.
     * 
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function mensagemProdutoInicial()
    {
        throw new self(
            "mnu_informe_produto_inicial",
            "Informe o produto inicial"
        );
    }
    
    /**
     * Excecao lancada para o caso de Produtos final n�o ser preeenchido.
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function mensagemProdutoFinal()
    {
        throw new self(
            "mnu_informe_produto_final",
            "Informe o produto final"
        );
    }
    
    /**
     * Excecao lancada para o caso de Data de entrega n�o ser preeenchida.
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function mensagemDataEntrega()
    {
        throw new self(
            "msg_dt_entrega",
            "Informe a data de entrega"
        );
    }
    
    /**
     * Excecao lancada para o caso de quantidade negativa.
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function mensagemQuantidadeMaiorZero()
    {
        throw new self(
            "msg_quantidade_maior_zero",
            "Quantidade deve ser maior que zero!"
        );
    }
    
    /**
     * Excecao lancada para o caso de justificativa de altera��on�o ser informada.
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function mensagemJustificativaAlteracao()
    {
        throw new self(
            "msg_informar_justificativa_alteracao",
            "Justificativa de altera��o deve ser informada."
        );
    }

    /**
     * Excecao lancada para o caso de o produto já estar aprovado para compra
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function mensagemProdExisteAprovado()
    {
        throw new self(
            "msg_quantidade_liberada_compra",
            "Quantidade já liberada para compra."
        );
    }

    /**
     * Excecao lancada para o caso de já haver itens aprovados na solicitacao
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function mensagemItemAprovado()
    {
        throw new self(
            "msg_solicitacao_possui_itens_aprovados",
            "Operação bloqueada! Solicitação já possui itens aprovados."
        );
    }

    /**
     * Excecao lancada para o caso da data ser menor que a data de processamento
     *
     * @return null
     * @throws CamposNaoPreenchidos
     */
    public static function mensagemDataProcessamento()
    {
        throw new self(
            "msg_data_maior_igual_data_processamento",
            "Data deve ser maior ou igual a data de processamento."
        );
    }
}
